==> rtfx-0.9.3.tar.gz: rtfx-0.9.3/src/rtfx.cpp <==
/*
 * Copyright (c) 2004, Nate Nielsen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *     * Redistributions of source code must retain the above 
 *       copyright notice, this list of conditions and the 
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the 
 *       above copyright notice, this list of conditions and 
 *       the following disclaimer in the documentation and/or 
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be 
 *       used to endorse or promote products derived from this 
 *       software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 * 
 *
 * CONTRIBUTORS
 *  Nate Nielsen <nielsen@memberwebs.com>
 *
 */ 

#include "usuals.h"
#include <stdlib.h>
#include <stdio.h>
#include <errno.h>

#include "rtfparser.h"
#include "xmlcomposer.h"

int usage()
{
	fprintf(stderr, "usage: rtfx [-p] <inrtf> <outxml>\n");
    exit(2);
}

int main(int argc, char* argv[])
{
    XmlComposerOptions options;
          
    while(argc > 1)
    {
        argc--;
        argv++;
        
        char* arg = argv[0];
        if(*arg != '-')
            break;

        while(arg && *(++arg))
        {
            switch(*arg)
            {
            case 'p':
                options.extras = true;
                break;
        
            case '-':
                arg = NULL;
                break;
            
            case '?':
            default:
                usage();
            }
        }

        if(arg == NULL)
            break;    
    }
        
	if(argc < 2)
		usage();

	try
	{
        // The input file 
		FILE* file = fopen(argv[0], "rb");

		if(!file)
		{
			fprintf(stderr, "rtfx: couldn't open rtf file: %s: %s\n", argv[0], strerror(errno));
			return 1;
		}

        // Reads RTF tags and blocks 
        RtfParser rtf;

        // Interprets tags and blocks from RTFParser 
		XmlComposer composer(options);
		rtf.setHandler(&composer);
        
		bool ret = rtf.parse(file);
		fclose(file);

		if(!ret)
		{
			fprintf(stderr, "rtfx: rtf parse failed: %s\n", rtf.getParseErrors().c_str());
			return 1;
		}

        // TODO: This is disgusting. We need to bug the sablotron guys
        // for a better way to serialize a document.
		DOM::Document doc = composer.getDocument();
		string xml = doc.serialize();

		FILE* out = fopen(argv[1], "wb");
		if(!out)
		{
			fprintf(stderr, "rtfx: couldn't open file: %s: %s\n", argv[1], strerror(errno));
			return 1;
		}

		fwrite(xml.c_str(), 1, xml.length(), out);
		fclose(out);
		return 0;
	}
	catch(DOM::DOMException& e)
	{
		fprintf(stderr, "rtfx: xml dom error: %s\n", e.getMessage());
	}

	return 1;
}

==> rtfx-1.1.tar.gz: rtfx-1.1/src/rtfx.cpp <==
/*
 * Copyright (c) 2004, Stefan Walter
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 * 
 *     * Redistributions of source code must retain the above 
 *       copyright notice, this list of conditions and the 
 *       following disclaimer.
 *     * Redistributions in binary form must reproduce the 
 *       above copyright notice, this list of conditions and 
 *       the following disclaimer in the documentation and/or 
 *       other materials provided with the distribution.
 *     * The names of contributors to this software may not be 
 *       used to endorse or promote products derived from this 
 *       software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH 
 * DAMAGE.
 * 
 *
 * CONTRIBUTORS
 *  Stef Walter <stef@memberwebs.com>
 *
 */ 

#include "usuals.h"
#include <stdlib.h>
#include <stdio.h>
#include <errno.h>

#include "rtfparser.h"
#include "xmlcomposer.h"

void usage()
{
	fprintf(stderr, "usage: rtfx [-pw] [inrtf] [outxml]\n");
	fprintf(stderr, "       rtfx -v\n");
    exit(2);
}

int main(int argc, char* argv[])
{
    XmlComposerOptions options;
    bool version = false;
	
    argc--;
    argv++;
    
    while(argc > 0)
    {
        char* arg = argv[0];
        if(*arg != '-')
            break;

        while(arg && *(++arg))
        {
            switch(*arg)
            {
            case 'p':
                options.extras = true;
                break;
			
			case 'w':
				options.pretty = true;
				break;
			
			case 'v':
				version = true;
				break;
        
            case '-':
                arg = NULL;
                break;
            
            case '?':
            default:
                usage();
            }
        }

        if(arg == NULL)
            break;    
    
	    argc--;
    	argv++;
    }
	
	if(version)
	{
		fprintf(stdout, "RTFX (version %s)\n", VERSION);
		return 0;
	}

    if(argc > 2)
    	usage();
        
	try
	{
		// By default no files
		FILE* file = NULL;
		FILE* out = stdout;
		
        // An input file
		if(argc > 0)
		{
    		file = fopen(argv[0], "rb");

			if(!file)
			{
				fprintf(stderr, "rtfx: couldn't open rtf file: %s: %s\n", argv[0], strerror(errno));
				return 1;
			}
			
			argc--;
			argv++;
		}
		
		// Use stdin
		else
		{
			// We have to do this instead of just use 'stdin' because windows
			// screws with the line endings of stdin.
			file = fdopen(0, "rb");
			
			if(!file)
			{
				fprintf(stderr, "rtfx: couldn't open stdin: %s", strerror(errno));
				return 1;
			}
		}
			
		
        // Reads RTF tags and blocks 
        RtfParser rtf;
		rtf.setUnicode(true);

        // Interprets tags and blocks from RTFParser 
		XmlComposer composer(options);
		rtf.setHandler(&composer);
        
		bool ret = rtf.parse(file);
		fclose(file);

		if(!ret)
		{
			fprintf(stderr, "rtfx: rtf parse failed: %s\n", rtf.getParseErrors().c_str());
			return 1;
		} 

		DOM::Document doc = composer.getDocument();

		if(argc > 0)
		{
			out = fopen(argv[0], "wb");
			if(!out)
			{
				fprintf(stderr, "rtfx: couldn't open output file: %s: %s\n", argv[0], strerror(errno));
				return 1;
			}
			
			argc--;
			argv++;
		}

        doc.serialize(out);
        
        if(out != stdout)
			fclose(out);
			
		return 0;
	}
	catch(DOM::DOMException& e)
	{
		fprintf(stderr, "rtfx: xml dom error: %s\n", e.getMessage());
	}

	return 1;
}
